#! /usr/bin/env python3

import cadquery as cq


# Create a single cube
cube = cq.Workplane("front").box(1, 1, 1)


def single_color_object():
    # Create an assembly
    assembly = cq.Assembly()
    color = cq.Color(0, 0, 1)

    # Add 4 cubes in a 2x2 grid
    for i in range(2):
        for j in range(2):
            assembly.add(
                cube,
                loc=cq.Location(
                    cq.Vector(i * 2, j * 2, 0),
                ),
                # Same object each time
                color=color,
            )

    return assembly

def multi_same_color_object():
    # Create an assembly
    assembly = cq.Assembly()

    # Add 4 cubes in a 2x2 grid
    for i in range(2):
        for j in range(2):
            assembly.add(
                cube,
                loc=cq.Location(
                    cq.Vector(i * 2, j * 2, 0),
                ),
                # This is always the same value, but it's a different object
                color=cq.Color(0, 0, 1),
            )

    return assembly

def multi_different_color_object():
    # Create an assembly
    assembly = cq.Assembly()
    color = cq.Color(0, 0, 1)

    # Add 4 cubes in a 2x2 grid
    for i in range(2):
        for j in range(2):
            # Change the color "secretly"
            color.r = i / 2
            color.g = j / 2
            color.b = 0
            assembly.add(
                cube,
                loc=cq.Location(
                    cq.Vector(i * 2, j * 2, 0),
                ),
                # Same object each time
                # but the value changed
                color=color,
            )

    return assembly

a_single_color_object = single_color_object()
a_single_color_object.save("cq_single_color.step", cq.exporters.ExportTypes.STEP)

a_multi_color_object = multi_same_color_object()
a_multi_color_object.save("cq_multi_same_color.step", cq.exporters.ExportTypes.STEP)

a_multi_color_object = multi_different_color_object()
a_multi_color_object.save("cq_multi_different_color.step", cq.exporters.ExportTypes.STEP)

# Show the sizes of the two files
import os

def print_file_size(file_name):
    print(f"Size of {file_name}: {os.path.getsize(file_name)} bytes")

print_file_size("cq_single_color.step")
print_file_size("cq_multi_same_color.step")
print_file_size("cq_multi_different_color.step")
